@@ -1,5 +1,5 @@
 /* GADMIN-SQUID - An easy to use GTK+ frontend for the Squid proxy server.
- * Copyright (C) 2006 - 2008 Magnus Loef <magnus-swe@telia.com> 
+ * Copyright (C) 2006 - 2009 Magnus Loef <magnus-swe@telia.com> 
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -19,7 +19,6 @@
 
 
 
-
 #include <gtk/gtk.h>
 #include <stdio.h>
 #include <stdlib.h>
@@ -137,10 +136,11 @@ int add_acls_to_buffer(GtkTreeModel *model, GtkTreePath *path,
           g_free(option2);
 	if( option3!=NULL )
           g_free(option3);
+
     	return FALSE;
     }
 
-    /* ACL definitions IE: "acl allnets 0.0.0.0/0.0.0.0" */
+    /* ACL definitions IE: "acl our_networks src something" */
     if( acl_type == 0 )
     {
         conf_line = g_strdup_printf("acl %s %s %s\n", option1, option2, option3);
@@ -182,7 +182,6 @@ void apply_server_settings(struct w *widgets)
     /* Change and save all server settings. */
     FILE *fp;
     gint active_index;
-//    gchar *info;
     char *config;
     GtkTreeModel *model;
     int i = 0;
@@ -281,10 +280,13 @@ void apply_server_settings(struct w *widgets)
 	strcat(opt_buffer, opt_line);
     }
 
-
     /* Add spinbutton settings to options buffer */
-    for(i=0; i<=80; i++)
+    for(i=0; i<=77; i++)
     {
+	/* Skip some out commented options */
+	if( i > 57 && i < 64 )
+	  continue;
+
         value = g_strdup_printf(gtk_entry_get_text(GTK_ENTRY(widgets->server_set_spinbutton[i])));
         if( value==NULL || strlen(value) < 1 )
 	{
@@ -347,118 +349,109 @@ void apply_server_settings(struct w *widgets)
     	if( i == 26 )
 	  snprintf(opt_line, 1000, "memory_pools_limit %s MB\n", value);
     	if( i == 27 )
-	  snprintf(opt_line, 1000, "wais_relay_port %s\n", value);
-    	if( i == 28 )
 	  snprintf(opt_line, 1000, "request_header_max_size %s KB\n", value);
-    	if( i == 29 )
+    	if( i == 28 )
 	  snprintf(opt_line, 1000, "request_body_max_size %s KB\n", value);
-    	if( i == 30 )
+    	if( i == 29 )
 	  snprintf(opt_line, 1000, "quick_abort_min %s KB\n", value);
-    	if( i == 31 )
+    	if( i == 30 )
 	  snprintf(opt_line, 1000, "quick_abort_max %s KB\n", value);
-    	if( i == 32 )
+    	if( i == 31 )
 	  snprintf(opt_line, 1000, "quick_abort_pct %s\n", value);
-    	if( i == 33 )
+    	if( i == 32 )
 	  snprintf(opt_line, 1000, "read_ahead_gap %s KB\n", value);
-    	if( i == 34 )
+    	if( i == 33 )
 	  snprintf(opt_line, 1000, "negative_ttl %s minutes\n", value);
-    	if( i == 35 )
+    	if( i == 34 )
 	  snprintf(opt_line, 1000, "positive_dns_ttl %s seconds\n", value);
-    	if( i == 36 )
+    	if( i == 35 )
 	  snprintf(opt_line, 1000, "negative_dns_ttl %s seconds\n", value);
-    	if( i == 37 )
+    	if( i == 36 )
 	  snprintf(opt_line, 1000, "range_offset_limit %s KB\n", value);
-    	if( i == 38 )
-	  snprintf(opt_line, 1000, "refresh_stale_hit %s\n", value);
-    	if( i == 39 )
+    	if( i == 37 )
 	  snprintf(opt_line, 1000, "client_lifetime %s day\n", value);
-    	if( i == 40 )
+    	if( i == 38 )
 	  snprintf(opt_line, 1000, "shutdown_lifetime %s seconds\n", value);
-    	if( i == 41 )
+    	if( i == 39 )
 	  snprintf(opt_line, 1000, "reply_header_max_size %s KB\n", value);
-    	if( i == 42 )
-	  snprintf(opt_line, 1000, "announce_period %s\n", value);
-    	if( i == 43 )
+    	if( i == 40 )
+	  snprintf(opt_line, 1000, "announce_period %s seconds\n", value);
+    	if( i == 41 )
 	  snprintf(opt_line, 1000, "announce_port %s\n", value);
-    	if( i == 44 )
+    	if( i == 42 )
 	  snprintf(opt_line, 1000, "logfile_rotate %s\n", value);
-    	if( i == 45 )
+    	if( i == 43 )
 	  snprintf(opt_line, 1000, "tcp_recv_bufsize %s bytes\n", value);
-    	if( i == 46 )
+    	if( i == 44 )
 	  snprintf(opt_line, 1000, "minimum_direct_hops %s\n", value);
-    	if( i == 47 )
+    	if( i == 45 )
 	  snprintf(opt_line, 1000, "minimum_direct_rtt %s\n", value);
-    	if( i == 48 )
+    	if( i == 46 )
 	  snprintf(opt_line, 1000, "store_avg_object_size %s KB\n", value);
-    	if( i == 49 )
+    	if( i == 47 )
 	  snprintf(opt_line, 1000, "store_objects_per_bucket %s\n", value);
-    	if( i == 50 )
+    	if( i == 48 )
 	  snprintf(opt_line, 1000, "netdb_low %s\n", value);
-    	if( i == 51 )
+    	if( i == 49 )
 	  snprintf(opt_line, 1000, "netdb_high %s\n", value);
-    	if( i == 52 )
+    	if( i == 50 )
 	  snprintf(opt_line, 1000, "netdb_ping_period %s minutes\n", value);
-    	if( i == 53 )
+    	if( i == 51 )
 	  snprintf(opt_line, 1000, "maximum_single_addr_tries %s\n", value);
-    	if( i == 54 )
+    	if( i == 52 )
 	  snprintf(opt_line, 1000, "wccp_version %s\n", value);
-    	if( i == 55 )
+    	if( i == 53 )
 	  snprintf(opt_line, 1000, "wccp2_forwarding_method %s\n", value);
-    	if( i == 56 )
+    	if( i == 54 )
 	  snprintf(opt_line, 1000, "wccp2_return_method %s\n", value);
-    	if( i == 57 )
+    	if( i == 55 )
 	  snprintf(opt_line, 1000, "wccp2_assignment_method %s\n", value);
-
-
-	// Use entry instead ?
-    	if( i == 58 ) // Can also be "wccp2_service dynamic 80 password=hey".
+    	if( i == 56 ) // Can also be "wccp2_service dynamic 80 password=hey".
 	  snprintf(opt_line, 1000, "wccp2_service standard %s\n", value);
-
-
-    	if( i == 59 )
+    	if( i == 57 )
 	  snprintf(opt_line, 1000, "wccp2_weight %s\n", value);
-    	if( i == 60 )
+/*
+    	if( i == 58 )
 	  snprintf(opt_line, 1000, "incoming_icp_average %s\n", value);
-    	if( i == 61 )
+    	if( i == 59 )
 	  snprintf(opt_line, 1000, "incoming_http_average %s\n", value);
-    	if( i == 62 )
+    	if( i == 60 )
 	  snprintf(opt_line, 1000, "incoming_dns_average %s\n", value);
-    	if( i == 63 )
+    	if( i == 61 )
 	  snprintf(opt_line, 1000, "min_icp_poll_cnt %s\n", value);
-    	if( i == 64 )
+    	if( i == 62 )
 	  snprintf(opt_line, 1000, "min_dns_poll_cnt %s\n", value);
-    	if( i == 65 )
+    	if( i == 63 )
 	  snprintf(opt_line, 1000, "min_http_poll_cnt %s\n", value);
-    	if( i == 66 )
+*/
+    	if( i == 64 )
 	  snprintf(opt_line, 1000, "max_open_disk_fds %s\n", value);
-    	if( i == 67 )
+    	if( i == 65 )
 	  snprintf(opt_line, 1000, "digest_bits_per_entry %s\n", value);
-    	if( i == 68 )
+    	if( i == 66 )
 	  snprintf(opt_line, 1000, "digest_rebuild_period %s seconds\n", value);
-    	if( i == 69 )
+    	if( i == 67 )
 	  snprintf(opt_line, 1000, "digest_rewrite_period %s seconds\n", value);
-    	if( i == 70 )
+    	if( i == 68 )
 	  snprintf(opt_line, 1000, "digest_swapout_chunk_size %s bytes\n", value);
-    	if( i == 71 )
+    	if( i == 69 )
 	  snprintf(opt_line, 1000, "digest_rebuild_chunk_percentage %s\n", value);
-    	if( i == 72 )
+    	if( i == 70 )
 	  snprintf(opt_line, 1000, "high_response_time_warning %s\n", value);
-    	if( i == 73 )
+    	if( i == 71 )
 	  snprintf(opt_line, 1000, "high_page_fault_warning %s\n", value);
-    	if( i == 74 )
-	  snprintf(opt_line, 1000, "high_memory_warning %s\n", value);
-    	if( i == 75 )
+    	if( i == 72 )
+	  snprintf(opt_line, 1000, "high_memory_warning %s bytes\n", value);
+    	if( i == 73 )
 	  snprintf(opt_line, 1000, "sleep_after_fork %s\n", value);
-    	if( i == 76 )
+    	if( i == 74 )
 	  snprintf(opt_line, 1000, "minimum_expiry_time %s seconds\n", value);
-    	if( i == 77 )
-	  snprintf(opt_line, 1000, "max_filedesc %s\n", value);
-    	if( i == 78 )
+    	if( i == 75 )
 	  snprintf(opt_line, 1000, "authenticate_cache_garbage_interval %s seconds\n", value);
-    	if( i == 79 )
+    	if( i == 76 )
 	  snprintf(opt_line, 1000, "authenticate_ttl %s seconds\n", value);
-    	if( i == 80 )
-	  snprintf(opt_line, 1000, "authenticate_ip_ttl %s\n", value);
+    	if( i == 77 )
+	  snprintf(opt_line, 1000, "authenticate_ip_ttl %s seconds\n", value);
 
 	/* Add spinbutton config values to the options buffer */
 	strcat(opt_buffer, opt_line);
@@ -466,7 +459,7 @@ void apply_server_settings(struct w *widgets)
 
 
     /* Add combo box settings to options buffer */
-    for(i=0; i<=48; i++)
+    for(i=0; i<=42; i++)
     {
 	active_index = gtk_combo_box_get_active(GTK_COMBO_BOX(widgets->server_set_combo[i]));
         if( active_index == 0 )
@@ -503,80 +496,68 @@ void apply_server_settings(struct w *widgets)
 	if( i == 10 )
 	  snprintf(opt_line, 1000, "memory_pools %s\n", value);
 	if( i == 11 )
-	  snprintf(opt_line, 1000, "acl_uses_indirect_client %s\n", value);
-	if( i == 12 )
 	  snprintf(opt_line, 1000, "half_closed_clients %s\n", value);
-	if( i == 13 )
+	if( i == 12 )
 	  snprintf(opt_line, 1000, "httpd_suppress_version_string %s\n", value);
-	if( i == 14 )
-	  snprintf(opt_line, 1000, "delay_pool_uses_indirect_client %s\n", value);
-	if( i == 15 )
-	  snprintf(opt_line, 1000, "log_uses_indirect_client %s\n", value);
-	if( i == 16 )
+	if( i == 13 )
 	  snprintf(opt_line, 1000, "via %s\n", value);
-	if( i == 17 )
+	if( i == 14 )
 	  snprintf(opt_line, 1000, "forwarded_for %s\n", value);
-	if( i == 18 )
+	if( i == 15 )
 	  snprintf(opt_line, 1000, "log_icp_queries %s\n", value);
-	if( i == 19 )
-	  snprintf(opt_line, 1000, "httpd_accel_no_pmtu_disc %s\n", value);
-	if( i == 20 )
+	if( i == 16 )
 	  snprintf(opt_line, 1000, "client_db %s\n", value);
-	if( i == 21 )
+	if( i == 17 )
 	  snprintf(opt_line, 1000, "icp_hit_stale %s\n", value);
-	if( i == 22 )
+	if( i == 18 )
 	  snprintf(opt_line, 1000, "query_icmp %s\n", value);
-	if( i == 23 )
+	if( i == 19 )
 	  snprintf(opt_line, 1000, "test_reachability %s\n", value);
-	if( i == 24 )
+	if( i == 20 )
 	  snprintf(opt_line, 1000, "buffered_logs %s\n", value);
-	if( i == 25 )
+	if( i == 21 )
 	  snprintf(opt_line, 1000, "reload_into_ims %s\n", value);
-	if( i == 26 )
+	if( i == 22 )
 	  snprintf(opt_line, 1000, "global_internal_static %s\n", value);
-	if( i == 27 )
+	if( i == 23 )
 	  snprintf(opt_line, 1000, "short_icon_urls %s\n", value);
-	if( i == 28 )
+	if( i == 24 )
 	  snprintf(opt_line, 1000, "offline_mode %s\n", value);
-	if( i == 29 )
+	if( i == 25 )
 	  snprintf(opt_line, 1000, "nonhierarchical_direct %s\n", value);
-	if( i == 30 )
+	if( i == 26 )
 	  snprintf(opt_line, 1000, "prefer_direct %s\n", value);
-	if( i == 31 )
+	if( i == 27 )
 	  snprintf(opt_line, 1000, "strip_query_terms %s\n", value);
-	if( i == 32 )
+	if( i == 28 )
 	  snprintf(opt_line, 1000, "redirector_bypass %s\n", value);
-	if( i == 33 )
+	if( i == 29 )
 	  snprintf(opt_line, 1000, "ignore_unknown_nameservers %s\n", value);
-	if( i == 34 )
+	if( i == 30 )
 	  snprintf(opt_line, 1000, "client_persistent_connections %s\n", value);
-	if( i == 35 )
+	if( i == 31 )
 	  snprintf(opt_line, 1000, "server_persistent_connections %s\n", value);
-	if( i == 36 )
+	if( i == 32 )
 	  snprintf(opt_line, 1000, "persistent_connection_after_error %s\n", value);
-	if( i == 37 )
+	if( i == 33 )
 	  snprintf(opt_line, 1000, "detect_broken_pconn %s\n", value);
-	if( i == 38 )
+	if( i == 34 )
 	  snprintf(opt_line, 1000, "balance_on_multiple_ip %s\n", value);
-	if( i == 39 )
+	if( i == 35 )
 	  snprintf(opt_line, 1000, "pipeline_prefetch %s\n", value);
-	if( i == 40 )
+	if( i == 36 )
 	  snprintf(opt_line, 1000, "request_entities %s\n", value);
-	if( i == 41 )
+	if( i == 37 )
 	  snprintf(opt_line, 1000, "ie_refresh %s\n", value);
-	if( i == 42 )
+	if( i == 38 )
 	  snprintf(opt_line, 1000, "vary_ignore_expire %s\n", value);
-	if( i == 43 )
+	if( i == 39 )
 	  snprintf(opt_line, 1000, "relaxed_header_parser %s\n", value);
-	if( i == 44 )
-	  snprintf(opt_line, 1000, "cache_vary %s\n", value);
-	if( i == 45 )
+	if( i == 40 )
 	  snprintf(opt_line, 1000, "retry_on_error %s\n", value);
-	if( i == 46 )
-	  snprintf(opt_line, 1000, "collapsed_forwarding %s\n", value);
-	if( i == 47 )
+	if( i == 41 )
 	  snprintf(opt_line, 1000, "wccp2_rebuild_wait %s\n", value);
-	if( i == 48 )
+	if( i == 42 )
 	  snprintf(opt_line, 1000, "digest_generation %s\n", value);
 
 	/* Add combo box config values to the options buffer */
@@ -606,6 +587,10 @@ void apply_server_settings(struct w *widgets)
     gtk_tree_model_foreach(GTK_TREE_MODEL(model),
                           (GtkTreeModelForeachFunc) &add_acls_to_buffer, widgets);
 
+    /* Add a newline between ACL's and ACL settings */
+    strcat(acl_buffer, "\n");
+
+
     /* Call foreach on the aclperms treeview 2 times with acl_type=1 to get all ACL settings */
     /* The acl_perm is used set correct "allow" then "deny" ordering */
     acl_type = 1;
@@ -636,8 +621,6 @@ len = strlen(acl_buffer);
 printf("ACL len: %d\n", len);  1083
 */
 
-//return;
-
     config = allocate(1024 + OPTION_BUFFER_MAX_SIZE + SERVER_BUFFER_MAX_SIZE + ACL_BUFFER_MAX_SIZE);
 
     /* Put all servers first in the configuration */
