@@ -1,5 +1,5 @@
 /* GADMIN-SQUID - An easy to use GTK+ frontend for the Squid proxy server.
- * Copyright (C) 2006 - 2008 Magnus Loef <magnus-swe@telia.com> 
+ * Copyright (C) 2006 - 2009 Magnus Loef <magnus-swe@telia.com> 
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -113,12 +113,13 @@ void delete_row_clicked(gpointer data, GtkTreeView *treeview)
 /* Populate acl_combo_list_1 in the second treeview
    with the contents of the first treeview's ACL Name list */
 gboolean names_foreach(GtkTreeModel *model, GtkTreePath *path,
-        		  GtkTreeIter *iter, char *unused) //int i) //, struct w *widgets)
+        		  GtkTreeIter *iter, char *unused)
 {
     GtkTreeIter new_iter;
     gchar *acl_name;
 
     gtk_tree_model_get(model, iter, 0, &acl_name, -1);
+
     if( acl_name !=NULL )
     {
 	gtk_list_store_append(acl_combo_list[3], &new_iter);
@@ -131,12 +132,17 @@ gboolean names_foreach(GtkTreeModel *model, GtkTreePath *path,
 void populate_aclperm_name_list(GtkListStore *store)
 {
     gchar *unused=NULL;
+    GtkTreeIter iter;
 
     /* Clear the aclperm treeviews Name list combo */
     gtk_list_store_clear(GTK_LIST_STORE(acl_combo_list[3]));
+
+    /* Squid-3.x. Has a built in 'all' rule so always add it first. */
+    gtk_list_store_append(acl_combo_list[3], &iter);
+    gtk_list_store_set(acl_combo_list[3], &iter, 0, "all", -1);
     
-    /* Iterate the name column of the first acl treeview 
-       and append the values to the aclperm name list */
+    /* Iterate the name column of the first acl treeview and append 
+       the values to the aclperm name list in the second treeview. */
     gtk_tree_model_foreach(GTK_TREE_MODEL(store),
     (GtkTreeModelForeachFunc) names_foreach, unused);
 }
@@ -447,21 +453,6 @@ void create_acl_tab(struct w *widgets)
     gtk_list_store_set(acl_combo_list[1], &iter, 0, "broken_posts", -1);
     gtk_list_store_append(acl_combo_list[1], &iter);
     gtk_list_store_set(acl_combo_list[1], &iter, 0, "miss_access", -1);
-    gtk_list_store_append(acl_combo_list[1], &iter);
-    gtk_list_store_set(acl_combo_list[1], &iter, 0, "follow_x_forwarded_for", -1);
-    gtk_list_store_append(acl_combo_list[1], &iter);
-    gtk_list_store_set(acl_combo_list[1], &iter, 0, "broken_vary_encoding", -1);
-    /* Some options have different formatting, the combo is editable... */
-    gtk_list_store_append(acl_combo_list[1], &iter);
-    gtk_list_store_set(acl_combo_list[1], &iter, 0, "reply_body_max_size 0", -1);
-    gtk_list_store_append(acl_combo_list[1], &iter);
-    gtk_list_store_set(acl_combo_list[1], &iter, 0, "reply_body_max_size 4096", -1);
-    gtk_list_store_append(acl_combo_list[1], &iter);
-    gtk_list_store_set(acl_combo_list[1], &iter, 0, "reply_body_max_size 8Mb", -1);
-    gtk_list_store_append(acl_combo_list[1], &iter);
-    gtk_list_store_set(acl_combo_list[1], &iter, 0, "reply_body_max_size 60Mb", -1);
-    gtk_list_store_append(acl_combo_list[1], &iter);
-    gtk_list_store_set(acl_combo_list[1], &iter, 0, "reply_body_max_size 120Mb", -1);
 
     /* Create popdown strings for aclperms_treeviews ACL Permission combo */
     acl_combo_list[2] = gtk_list_store_new(1, G_TYPE_STRING);
@@ -495,6 +486,7 @@ void create_acl_tab(struct w *widgets)
 
     /* Add column numbers to the cells */
     g_object_set_data(G_OBJECT(combo_cell[0]), "column", (void*)(1));
+
     /* Second treeview's cells */
     g_object_set_data(G_OBJECT(combo_cell[1]), "column", (void*)(0));
     g_object_set_data(G_OBJECT(combo_cell[2]), "column", (void*)(1));
