@@ -1,5 +1,5 @@
 /* GADMIN-SQUID - An easy to use GTK+ frontend for the Squid proxy server.
- * Copyright (C) 2006 - 2008 Magnus Loef <magnus-swe@telia.com> 
+ * Copyright (C) 2006 - 2009 Magnus Loef <magnus-swe@telia.com> 
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -505,18 +505,6 @@ void create_server_settings(struct w *widgets)
     gtk_tooltips_set_tip(tooltips, widgets->server_set_spinbutton[spin], _("IE: 5 MB"), NULL);
     a++; b++; spin++;
 
-    /* acl_uses_indirect_client */
-    widgets->server_set_combo[comb] = make_short_combo_with_label(GTK_TABLE(widgets->srv_set_table),
-    _(" ACL uses indirect client: "), 0,1,a,b,50);
-    combo_text = g_strdup_printf(_("On"));
-    utf8 = g_locale_to_utf8(combo_text, strlen(combo_text), NULL, NULL, NULL);
-    gtk_combo_box_append_text(GTK_COMBO_BOX(widgets->server_set_combo[comb]), utf8);
-    combo_text = g_strdup_printf(_("Off"));
-    utf8 = g_locale_to_utf8(combo_text, strlen(combo_text), NULL, NULL, NULL);
-    gtk_combo_box_append_text(GTK_COMBO_BOX(widgets->server_set_combo[comb]), utf8);
-    g_free(combo_text); g_free(utf8);
-    a++; b++; comb++;
-
     /* half_closed_clients */
     widgets->server_set_combo[comb] = make_short_combo_with_label(GTK_TABLE(widgets->srv_set_table),
     _(" Half closed clients: "), 0,1,a,b,50);
@@ -541,30 +529,6 @@ void create_server_settings(struct w *widgets)
     g_free(combo_text); g_free(utf8);
     a++; b++; comb++;
 
-    /* delay_pool_uses_indirect_client */
-    widgets->server_set_combo[comb] = make_short_combo_with_label(GTK_TABLE(widgets->srv_set_table),
-    _(" Delay pool uses indirect client: "), 0,1,a,b,50);
-    combo_text = g_strdup_printf(_("On"));
-    utf8 = g_locale_to_utf8(combo_text, strlen(combo_text), NULL, NULL, NULL);
-    gtk_combo_box_append_text(GTK_COMBO_BOX(widgets->server_set_combo[comb]), utf8);
-    combo_text = g_strdup_printf(_("Off"));
-    utf8 = g_locale_to_utf8(combo_text, strlen(combo_text), NULL, NULL, NULL);
-    gtk_combo_box_append_text(GTK_COMBO_BOX(widgets->server_set_combo[comb]), utf8);
-    g_free(combo_text); g_free(utf8);
-    a++; b++; comb++;
-
-    /* log_uses_indirect_client */
-    widgets->server_set_combo[comb] = make_short_combo_with_label(GTK_TABLE(widgets->srv_set_table),
-    _(" Log uses indirect client: "), 0,1,a,b,50);
-    combo_text = g_strdup_printf(_("On"));
-    utf8 = g_locale_to_utf8(combo_text, strlen(combo_text), NULL, NULL, NULL);
-    gtk_combo_box_append_text(GTK_COMBO_BOX(widgets->server_set_combo[comb]), utf8);
-    combo_text = g_strdup_printf(_("Off"));
-    utf8 = g_locale_to_utf8(combo_text, strlen(combo_text), NULL, NULL, NULL);
-    gtk_combo_box_append_text(GTK_COMBO_BOX(widgets->server_set_combo[comb]), utf8);
-    g_free(combo_text); g_free(utf8);
-    a++; b++; comb++;
-
     /* via */
     widgets->server_set_combo[comb] = make_short_combo_with_label(GTK_TABLE(widgets->srv_set_table),
     _(" Proxy via: "), 0,1,a,b,50);
@@ -601,18 +565,6 @@ void create_server_settings(struct w *widgets)
     g_free(combo_text); g_free(utf8);
     a++; b++; comb++;
 
-    /* httpd_accel_no_pmtu_disc */
-    widgets->server_set_combo[comb] = make_short_combo_with_label(GTK_TABLE(widgets->srv_set_table),
-    _(" HTTPD accel no pmtu disc: "), 0,1,a,b,50);
-    combo_text = g_strdup_printf(_("On"));
-    utf8 = g_locale_to_utf8(combo_text, strlen(combo_text), NULL, NULL, NULL);
-    gtk_combo_box_append_text(GTK_COMBO_BOX(widgets->server_set_combo[comb]), utf8);
-    combo_text = g_strdup_printf(_("Off"));
-    utf8 = g_locale_to_utf8(combo_text, strlen(combo_text), NULL, NULL, NULL);
-    gtk_combo_box_append_text(GTK_COMBO_BOX(widgets->server_set_combo[comb]), utf8);
-    g_free(combo_text); g_free(utf8);
-    a++; b++; comb++;
-
     /* client_db */
     widgets->server_set_combo[comb] = make_short_combo_with_label(GTK_TABLE(widgets->srv_set_table),
     _(" Client database: "), 0,1,a,b,50);
@@ -907,18 +859,6 @@ void create_server_settings(struct w *widgets)
     g_free(combo_text); g_free(utf8);
     a++; b++; comb++;
 
-    /* cache_vary */
-    widgets->server_set_combo[comb] = make_short_combo_with_label(GTK_TABLE(widgets->srv_set_table),
-    _(" Cache vary: "), 0,1,a,b,50);
-    combo_text = g_strdup_printf(_("On"));
-    utf8 = g_locale_to_utf8(combo_text, strlen(combo_text), NULL, NULL, NULL);
-    gtk_combo_box_append_text(GTK_COMBO_BOX(widgets->server_set_combo[comb]), utf8);
-    combo_text = g_strdup_printf(_("Off"));
-    utf8 = g_locale_to_utf8(combo_text, strlen(combo_text), NULL, NULL, NULL);
-    gtk_combo_box_append_text(GTK_COMBO_BOX(widgets->server_set_combo[comb]), utf8);
-    g_free(combo_text); g_free(utf8);
-    a++; b++; comb++;
-
     /* retry_on_error */
     widgets->server_set_combo[comb] = make_short_combo_with_label(GTK_TABLE(widgets->srv_set_table),
     _(" Retry on error: "), 0,1,a,b,50);
@@ -931,18 +871,6 @@ void create_server_settings(struct w *widgets)
     g_free(combo_text); g_free(utf8);
     a++; b++; comb++;
 
-    /* collapsed_forwarding */
-    widgets->server_set_combo[comb] = make_short_combo_with_label(GTK_TABLE(widgets->srv_set_table),
-    _(" Collapsed forwarding: "), 0,1,a,b,50);
-    combo_text = g_strdup_printf(_("On"));
-    utf8 = g_locale_to_utf8(combo_text, strlen(combo_text), NULL, NULL, NULL);
-    gtk_combo_box_append_text(GTK_COMBO_BOX(widgets->server_set_combo[comb]), utf8);
-    combo_text = g_strdup_printf(_("Off"));
-    utf8 = g_locale_to_utf8(combo_text, strlen(combo_text), NULL, NULL, NULL);
-    gtk_combo_box_append_text(GTK_COMBO_BOX(widgets->server_set_combo[comb]), utf8);
-    g_free(combo_text); g_free(utf8);
-    a++; b++; comb++;
-
     /* Server user */
     widgets->server_set_entry[ent] = make_long_entry_with_label(GTK_TABLE(widgets->srv_set_table),
     _(" The server runs as this user: "), 0,1,a,b,200);
@@ -973,12 +901,6 @@ void create_server_settings(struct w *widgets)
     gtk_tooltips_set_tip(tooltips, widgets->server_set_entry[ent], _("..."), NULL);
     a++; b++; ent++;
 
-    /* wais_relay_port */
-    widgets->server_set_spinbutton[spin] = make_short_spinbutton_with_label(GTK_TABLE(widgets->srv_set_table),
-    _(" Wais relay port: "), 0,1,a,b,50);
-    gtk_tooltips_set_tip(tooltips, widgets->server_set_spinbutton[spin], _("Blah"), NULL);
-    a++; b++; spin++;
-
     /* request_header_max_size */
     widgets->server_set_spinbutton[spin] = make_short_spinbutton_with_label(GTK_TABLE(widgets->srv_set_table),
     _(" Request header max size: "), 0,1,a,b,50);
@@ -1039,12 +961,6 @@ void create_server_settings(struct w *widgets)
     gtk_tooltips_set_tip(tooltips, widgets->server_set_spinbutton[spin], _("Blah"), NULL);
     a++; b++; spin++;
 
-    /* refresh_stale_hit */
-    widgets->server_set_spinbutton[spin] = make_short_spinbutton_with_label(GTK_TABLE(widgets->srv_set_table),
-    _(" Refresh stale hits: "), 0,1,a,b,50);
-    gtk_tooltips_set_tip(tooltips, widgets->server_set_spinbutton[spin], _("Blah"), NULL);
-    a++; b++; spin++;
-
     /* client_lifetime */
     widgets->server_set_spinbutton[spin] = make_short_spinbutton_with_label(GTK_TABLE(widgets->srv_set_table),
     _(" Client lifetime: "), 0,1,a,b,50);
@@ -1214,40 +1130,52 @@ void create_server_settings(struct w *widgets)
     a++; b++; spin++;
 
     /* incoming_icp_average */
-    widgets->server_set_spinbutton[spin] = make_short_spinbutton_with_label(GTK_TABLE(widgets->srv_set_table),
+/*    widgets->server_set_spinbutton[spin] = make_short_spinbutton_with_label(GTK_TABLE(widgets->srv_set_table),
     _(" Incoming ICP average: "), 0,1,a,b,50);
     gtk_tooltips_set_tip(tooltips, widgets->server_set_spinbutton[spin], _("Blah"), NULL);
     a++; b++; spin++;
+*/
+    spin++;
 
     /* incoming_http_average */
-    widgets->server_set_spinbutton[spin] = make_short_spinbutton_with_label(GTK_TABLE(widgets->srv_set_table),
+/*    widgets->server_set_spinbutton[spin] = make_short_spinbutton_with_label(GTK_TABLE(widgets->srv_set_table),
     _(" Incoming HTTP average: "), 0,1,a,b,50);
     gtk_tooltips_set_tip(tooltips, widgets->server_set_spinbutton[spin], _("Blah"), NULL);
     a++; b++; spin++;
+*/
+    spin++;
 
     /* incoming_dns_average */
-    widgets->server_set_spinbutton[spin] = make_short_spinbutton_with_label(GTK_TABLE(widgets->srv_set_table),
+/*    widgets->server_set_spinbutton[spin] = make_short_spinbutton_with_label(GTK_TABLE(widgets->srv_set_table),
     _(" Incoming DNS average: "), 0,1,a,b,50);
     gtk_tooltips_set_tip(tooltips, widgets->server_set_spinbutton[spin], _("Blah"), NULL);
     a++; b++; spin++;
+*/
+    spin++;
 
     /* min_icp_poll_cnt */
-    widgets->server_set_spinbutton[spin] = make_short_spinbutton_with_label(GTK_TABLE(widgets->srv_set_table),
+/*    widgets->server_set_spinbutton[spin] = make_short_spinbutton_with_label(GTK_TABLE(widgets->srv_set_table),
     _(" Minimum ICP poll count: "), 0,1,a,b,50);
     gtk_tooltips_set_tip(tooltips, widgets->server_set_spinbutton[spin], _("Blah"), NULL);
     a++; b++; spin++;
+*/
+    spin++;
 
     /* min_dns_poll_cnt */
-    widgets->server_set_spinbutton[spin] = make_short_spinbutton_with_label(GTK_TABLE(widgets->srv_set_table),
+/*    widgets->server_set_spinbutton[spin] = make_short_spinbutton_with_label(GTK_TABLE(widgets->srv_set_table),
     _(" Minimum DNS poll count: "), 0,1,a,b,50);
     gtk_tooltips_set_tip(tooltips, widgets->server_set_spinbutton[spin], _("Blah"), NULL);
     a++; b++; spin++;
+*/
+    spin++;
 
     /* min_http_poll_cnt */
-    widgets->server_set_spinbutton[spin] = make_short_spinbutton_with_label(GTK_TABLE(widgets->srv_set_table),
+/*    widgets->server_set_spinbutton[spin] = make_short_spinbutton_with_label(GTK_TABLE(widgets->srv_set_table),
     _(" Minimum HTTP poll count: "), 0,1,a,b,50);
     gtk_tooltips_set_tip(tooltips, widgets->server_set_spinbutton[spin], _("Blah"), NULL);
     a++; b++; spin++;
+*/
+    spin++;
 
     /* max_open_disk_fds */
     widgets->server_set_spinbutton[spin] = make_short_spinbutton_with_label(GTK_TABLE(widgets->srv_set_table),
@@ -1333,12 +1261,6 @@ void create_server_settings(struct w *widgets)
     gtk_tooltips_set_tip(tooltips, widgets->server_set_spinbutton[spin], _("Blah"), NULL);
     a++; b++; spin++;
 
-    /* max_filedesc */
-    widgets->server_set_spinbutton[spin] = make_short_spinbutton_with_label(GTK_TABLE(widgets->srv_set_table),
-    _(" Maximum file descriptors: "), 0,1,a,b,50);
-    gtk_tooltips_set_tip(tooltips, widgets->server_set_spinbutton[spin], _("Blah"), NULL);
-    a++; b++; spin++;
-
     /* authenticate_cache_garbage_interval */
     widgets->server_set_spinbutton[spin] = make_short_spinbutton_with_label(GTK_TABLE(widgets->srv_set_table),
     _(" Authenticate cache garbage interval: "), 0,1,a,b,50);
