@@ -1,5 +1,5 @@
 /* GADMIN-SQUID - An easy to use GTK+ frontend for the Squid proxy server.
- * Copyright (C) 2006 - 2008 Magnus Loef <magnus-swe@telia.com> 
+ * Copyright (C) 2006 - 2009 Magnus Loef <magnus-swe@telia.com> 
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -866,8 +866,7 @@ char *random_string(int len)
 	{
 	    where = rand() % 106;
     	  
-	    if( u_arr[where]!="0" && u_arr[where]!="1" && u_arr[where]!="2" && u_arr[where]!="3" && u_arr[where]!="4"
-	    &&  u_arr[where]!="5" && u_arr[where]!="6" && u_arr[where]!="7" && u_arr[where]!="8" && u_arr[where]!="9" )
+	    if( ! chars_are_digits(u_arr[where]) )
 	    {
 		strcpy(rnd_string, u_arr[where]);
                 break;
@@ -878,8 +877,7 @@ char *random_string(int len)
 	{
 	    where = rand() % 53;
 
-            if( l_arr[where]!="0" && l_arr[where]!="1" && l_arr[where]!="2" && l_arr[where]!="3" && l_arr[where]!="4"
-	    &&  l_arr[where]!="5" && l_arr[where]!="6" && l_arr[where]!="7" && l_arr[where]!="8" && l_arr[where]!="9" )
+	    if( ! chars_are_digits(l_arr[where]) )
 	    {
 		strcpy(rnd_string, l_arr[where]);
     	        break;
