@@ -1,5 +1,5 @@
 /* GADMIN-SQUID - An easy to use GTK+ frontend for the Squid proxy server.
- * Copyright (C) 2006 - 2008 Magnus Loef <magnus-swe@telia.com> 
+ * Copyright (C) 2006 - 2009 Magnus Loef <magnus-swe@telia.com> 
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -834,7 +834,7 @@ void populate_server_settings(struct w *widgets)
         	gtk_spin_button_set_value(GTK_SPIN_BUTTON(widgets->server_set_spinbutton[26]), val);
 	    }
 	}
-	if( ! strcmp(firstopt, "wais_relay_port") )
+	if( ! strcmp(firstopt, "request_header_max_size") )
 	{
 	    opt_pos = get_option_pos(line, 1);
 	    snprintf(new_buffer, 1024, "%s", &line[opt_pos]);
@@ -849,7 +849,7 @@ void populate_server_settings(struct w *widgets)
         	gtk_spin_button_set_value(GTK_SPIN_BUTTON(widgets->server_set_spinbutton[27]), val);
 	    }
 	}
-	if( ! strcmp(firstopt, "request_header_max_size") )
+	if( ! strcmp(firstopt, "request_body_max_size") )
 	{
 	    opt_pos = get_option_pos(line, 1);
 	    snprintf(new_buffer, 1024, "%s", &line[opt_pos]);
@@ -864,7 +864,7 @@ void populate_server_settings(struct w *widgets)
         	gtk_spin_button_set_value(GTK_SPIN_BUTTON(widgets->server_set_spinbutton[28]), val);
 	    }
 	}
-	if( ! strcmp(firstopt, "request_body_max_size") )
+	if( ! strcmp(firstopt, "quick_abort_min") )
 	{
 	    opt_pos = get_option_pos(line, 1);
 	    snprintf(new_buffer, 1024, "%s", &line[opt_pos]);
@@ -879,7 +879,7 @@ void populate_server_settings(struct w *widgets)
         	gtk_spin_button_set_value(GTK_SPIN_BUTTON(widgets->server_set_spinbutton[29]), val);
 	    }
 	}
-	if( ! strcmp(firstopt, "quick_abort_min") )
+	if( ! strcmp(firstopt, "quick_abort_max") )
 	{
 	    opt_pos = get_option_pos(line, 1);
 	    snprintf(new_buffer, 1024, "%s", &line[opt_pos]);
@@ -894,7 +894,7 @@ void populate_server_settings(struct w *widgets)
         	gtk_spin_button_set_value(GTK_SPIN_BUTTON(widgets->server_set_spinbutton[30]), val);
 	    }
 	}
-	if( ! strcmp(firstopt, "quick_abort_max") )
+	if( ! strcmp(firstopt, "quick_abort_pct") )
 	{
 	    opt_pos = get_option_pos(line, 1);
 	    snprintf(new_buffer, 1024, "%s", &line[opt_pos]);
@@ -909,7 +909,7 @@ void populate_server_settings(struct w *widgets)
         	gtk_spin_button_set_value(GTK_SPIN_BUTTON(widgets->server_set_spinbutton[31]), val);
 	    }
 	}
-	if( ! strcmp(firstopt, "quick_abort_pct") )
+	if( ! strcmp(firstopt, "read_ahead_gap") )
 	{
 	    opt_pos = get_option_pos(line, 1);
 	    snprintf(new_buffer, 1024, "%s", &line[opt_pos]);
@@ -924,7 +924,7 @@ void populate_server_settings(struct w *widgets)
         	gtk_spin_button_set_value(GTK_SPIN_BUTTON(widgets->server_set_spinbutton[32]), val);
 	    }
 	}
-	if( ! strcmp(firstopt, "read_ahead_gap") )
+	if( ! strcmp(firstopt, "negative_ttl") )
 	{
 	    opt_pos = get_option_pos(line, 1);
 	    snprintf(new_buffer, 1024, "%s", &line[opt_pos]);
@@ -939,7 +939,7 @@ void populate_server_settings(struct w *widgets)
         	gtk_spin_button_set_value(GTK_SPIN_BUTTON(widgets->server_set_spinbutton[33]), val);
 	    }
 	}
-	if( ! strcmp(firstopt, "negative_ttl") )
+	if( ! strcmp(firstopt, "positive_dns_ttl") )
 	{
 	    opt_pos = get_option_pos(line, 1);
 	    snprintf(new_buffer, 1024, "%s", &line[opt_pos]);
@@ -954,7 +954,7 @@ void populate_server_settings(struct w *widgets)
         	gtk_spin_button_set_value(GTK_SPIN_BUTTON(widgets->server_set_spinbutton[34]), val);
 	    }
 	}
-	if( ! strcmp(firstopt, "positive_dns_ttl") )
+	if( ! strcmp(firstopt, "negative_dns_ttl") )
 	{
 	    opt_pos = get_option_pos(line, 1);
 	    snprintf(new_buffer, 1024, "%s", &line[opt_pos]);
@@ -969,7 +969,7 @@ void populate_server_settings(struct w *widgets)
         	gtk_spin_button_set_value(GTK_SPIN_BUTTON(widgets->server_set_spinbutton[35]), val);
 	    }
 	}
-	if( ! strcmp(firstopt, "negative_dns_ttl") )
+	if( ! strcmp(firstopt, "range_offset_limit") )
 	{
 	    opt_pos = get_option_pos(line, 1);
 	    snprintf(new_buffer, 1024, "%s", &line[opt_pos]);
@@ -984,7 +984,7 @@ void populate_server_settings(struct w *widgets)
         	gtk_spin_button_set_value(GTK_SPIN_BUTTON(widgets->server_set_spinbutton[36]), val);
 	    }
 	}
-	if( ! strcmp(firstopt, "range_offset_limit") )
+	if( ! strcmp(firstopt, "client_lifetime") )
 	{
 	    opt_pos = get_option_pos(line, 1);
 	    snprintf(new_buffer, 1024, "%s", &line[opt_pos]);
@@ -999,7 +999,7 @@ void populate_server_settings(struct w *widgets)
         	gtk_spin_button_set_value(GTK_SPIN_BUTTON(widgets->server_set_spinbutton[37]), val);
 	    }
 	}
-	if( ! strcmp(firstopt, "refresh_stale_hit") ) // FIXME: or _hits ?
+	if( ! strcmp(firstopt, "shutdown_lifetime") )
 	{
 	    opt_pos = get_option_pos(line, 1);
 	    snprintf(new_buffer, 1024, "%s", &line[opt_pos]);
@@ -1014,7 +1014,7 @@ void populate_server_settings(struct w *widgets)
         	gtk_spin_button_set_value(GTK_SPIN_BUTTON(widgets->server_set_spinbutton[38]), val);
 	    }
 	}
-	if( ! strcmp(firstopt, "client_lifetime") )
+	if( ! strcmp(firstopt, "reply_header_max_size") )
 	{
 	    opt_pos = get_option_pos(line, 1);
 	    snprintf(new_buffer, 1024, "%s", &line[opt_pos]);
@@ -1029,7 +1029,7 @@ void populate_server_settings(struct w *widgets)
         	gtk_spin_button_set_value(GTK_SPIN_BUTTON(widgets->server_set_spinbutton[39]), val);
 	    }
 	}
-	if( ! strcmp(firstopt, "shutdown_lifetime") )
+	if( ! strcmp(firstopt, "announce_period") )
 	{
 	    opt_pos = get_option_pos(line, 1);
 	    snprintf(new_buffer, 1024, "%s", &line[opt_pos]);
@@ -1044,7 +1044,7 @@ void populate_server_settings(struct w *widgets)
         	gtk_spin_button_set_value(GTK_SPIN_BUTTON(widgets->server_set_spinbutton[40]), val);
 	    }
 	}
-	if( ! strcmp(firstopt, "reply_header_max_size") )
+	if( ! strcmp(firstopt, "announce_port") )
 	{
 	    opt_pos = get_option_pos(line, 1);
 	    snprintf(new_buffer, 1024, "%s", &line[opt_pos]);
@@ -1059,7 +1059,7 @@ void populate_server_settings(struct w *widgets)
         	gtk_spin_button_set_value(GTK_SPIN_BUTTON(widgets->server_set_spinbutton[41]), val);
 	    }
 	}
-	if( ! strcmp(firstopt, "announce_period") )
+	if( ! strcmp(firstopt, "logfile_rotate") )
 	{
 	    opt_pos = get_option_pos(line, 1);
 	    snprintf(new_buffer, 1024, "%s", &line[opt_pos]);
@@ -1074,7 +1074,7 @@ void populate_server_settings(struct w *widgets)
         	gtk_spin_button_set_value(GTK_SPIN_BUTTON(widgets->server_set_spinbutton[42]), val);
 	    }
 	}
-	if( ! strcmp(firstopt, "announce_port") )
+	if( ! strcmp(firstopt, "tcp_recv_bufsize") )
 	{
 	    opt_pos = get_option_pos(line, 1);
 	    snprintf(new_buffer, 1024, "%s", &line[opt_pos]);
@@ -1089,7 +1089,7 @@ void populate_server_settings(struct w *widgets)
         	gtk_spin_button_set_value(GTK_SPIN_BUTTON(widgets->server_set_spinbutton[43]), val);
 	    }
 	}
-	if( ! strcmp(firstopt, "logfile_rotate") )
+	if( ! strcmp(firstopt, "minimum_direct_hops") )
 	{
 	    opt_pos = get_option_pos(line, 1);
 	    snprintf(new_buffer, 1024, "%s", &line[opt_pos]);
@@ -1104,7 +1104,7 @@ void populate_server_settings(struct w *widgets)
         	gtk_spin_button_set_value(GTK_SPIN_BUTTON(widgets->server_set_spinbutton[44]), val);
 	    }
 	}
-	if( ! strcmp(firstopt, "tcp_recv_bufsize") )
+	if( ! strcmp(firstopt, "minimum_direct_rtt") )
 	{
 	    opt_pos = get_option_pos(line, 1);
 	    snprintf(new_buffer, 1024, "%s", &line[opt_pos]);
@@ -1119,7 +1119,7 @@ void populate_server_settings(struct w *widgets)
         	gtk_spin_button_set_value(GTK_SPIN_BUTTON(widgets->server_set_spinbutton[45]), val);
 	    }
 	}
-	if( ! strcmp(firstopt, "minimum_direct_hops") )
+	if( ! strcmp(firstopt, "store_avg_object_size") )
 	{
 	    opt_pos = get_option_pos(line, 1);
 	    snprintf(new_buffer, 1024, "%s", &line[opt_pos]);
@@ -1134,7 +1134,7 @@ void populate_server_settings(struct w *widgets)
         	gtk_spin_button_set_value(GTK_SPIN_BUTTON(widgets->server_set_spinbutton[46]), val);
 	    }
 	}
-	if( ! strcmp(firstopt, "minimum_direct_rtt") )
+	if( ! strcmp(firstopt, "store_objects_per_bucket") )
 	{
 	    opt_pos = get_option_pos(line, 1);
 	    snprintf(new_buffer, 1024, "%s", &line[opt_pos]);
@@ -1149,7 +1149,7 @@ void populate_server_settings(struct w *widgets)
         	gtk_spin_button_set_value(GTK_SPIN_BUTTON(widgets->server_set_spinbutton[47]), val);
 	    }
 	}
-	if( ! strcmp(firstopt, "store_avg_object_size") )
+	if( ! strcmp(firstopt, "netdb_low") )
 	{
 	    opt_pos = get_option_pos(line, 1);
 	    snprintf(new_buffer, 1024, "%s", &line[opt_pos]);
@@ -1164,7 +1164,7 @@ void populate_server_settings(struct w *widgets)
         	gtk_spin_button_set_value(GTK_SPIN_BUTTON(widgets->server_set_spinbutton[48]), val);
 	    }
 	}
-	if( ! strcmp(firstopt, "store_objects_per_bucket") )
+	if( ! strcmp(firstopt, "netdb_high") )
 	{
 	    opt_pos = get_option_pos(line, 1);
 	    snprintf(new_buffer, 1024, "%s", &line[opt_pos]);
@@ -1179,7 +1179,7 @@ void populate_server_settings(struct w *widgets)
         	gtk_spin_button_set_value(GTK_SPIN_BUTTON(widgets->server_set_spinbutton[49]), val);
 	    }
 	}
-	if( ! strcmp(firstopt, "netdb_low") )
+	if( ! strcmp(firstopt, "netdb_ping_period") )
 	{
 	    opt_pos = get_option_pos(line, 1);
 	    snprintf(new_buffer, 1024, "%s", &line[opt_pos]);
@@ -1194,7 +1194,7 @@ void populate_server_settings(struct w *widgets)
         	gtk_spin_button_set_value(GTK_SPIN_BUTTON(widgets->server_set_spinbutton[50]), val);
 	    }
 	}
-	if( ! strcmp(firstopt, "netdb_high") )
+	if( ! strcmp(firstopt, "maximum_single_addr_tries") )
 	{
 	    opt_pos = get_option_pos(line, 1);
 	    snprintf(new_buffer, 1024, "%s", &line[opt_pos]);
@@ -1209,7 +1209,7 @@ void populate_server_settings(struct w *widgets)
         	gtk_spin_button_set_value(GTK_SPIN_BUTTON(widgets->server_set_spinbutton[51]), val);
 	    }
 	}
-	if( ! strcmp(firstopt, "netdb_ping_period") )
+	if( ! strcmp(firstopt, "wccp_version") )
 	{
 	    opt_pos = get_option_pos(line, 1);
 	    snprintf(new_buffer, 1024, "%s", &line[opt_pos]);
@@ -1224,7 +1224,7 @@ void populate_server_settings(struct w *widgets)
         	gtk_spin_button_set_value(GTK_SPIN_BUTTON(widgets->server_set_spinbutton[52]), val);
 	    }
 	}
-	if( ! strcmp(firstopt, "maximum_single_addr_tries") )
+	if( ! strcmp(firstopt, "wccp2_forwarding_method") )
 	{
 	    opt_pos = get_option_pos(line, 1);
 	    snprintf(new_buffer, 1024, "%s", &line[opt_pos]);
@@ -1239,7 +1239,7 @@ void populate_server_settings(struct w *widgets)
         	gtk_spin_button_set_value(GTK_SPIN_BUTTON(widgets->server_set_spinbutton[53]), val);
 	    }
 	}
-	if( ! strcmp(firstopt, "wccp_version") )
+	if( ! strcmp(firstopt, "wccp2_return_method") )
 	{
 	    opt_pos = get_option_pos(line, 1);
 	    snprintf(new_buffer, 1024, "%s", &line[opt_pos]);
@@ -1254,7 +1254,7 @@ void populate_server_settings(struct w *widgets)
         	gtk_spin_button_set_value(GTK_SPIN_BUTTON(widgets->server_set_spinbutton[54]), val);
 	    }
 	}
-	if( ! strcmp(firstopt, "wccp2_forwarding_method") )
+	if( ! strcmp(firstopt, "wccp2_assignment_method") )
 	{
 	    opt_pos = get_option_pos(line, 1);
 	    snprintf(new_buffer, 1024, "%s", &line[opt_pos]);
@@ -1269,7 +1269,7 @@ void populate_server_settings(struct w *widgets)
         	gtk_spin_button_set_value(GTK_SPIN_BUTTON(widgets->server_set_spinbutton[55]), val);
 	    }
 	}
-	if( ! strcmp(firstopt, "wccp2_return_method") )
+	if( ! strcmp(firstopt, "wccp2_service") ) // FIXME: "wccp2_service standard/dynamic 2" Entry ?
 	{
 	    opt_pos = get_option_pos(line, 1);
 	    snprintf(new_buffer, 1024, "%s", &line[opt_pos]);
@@ -1284,7 +1284,7 @@ void populate_server_settings(struct w *widgets)
         	gtk_spin_button_set_value(GTK_SPIN_BUTTON(widgets->server_set_spinbutton[56]), val);
 	    }
 	}
-	if( ! strcmp(firstopt, "wccp2_assignment_method") )
+	if( ! strcmp(firstopt, "wccp2_weight") )
 	{
 	    opt_pos = get_option_pos(line, 1);
 	    snprintf(new_buffer, 1024, "%s", &line[opt_pos]);
@@ -1299,7 +1299,8 @@ void populate_server_settings(struct w *widgets)
         	gtk_spin_button_set_value(GTK_SPIN_BUTTON(widgets->server_set_spinbutton[57]), val);
 	    }
 	}
-	if( ! strcmp(firstopt, "wccp2_service") ) // FIXME: "wccp2_service standard/dynamic 2" Entry ?
+/*
+	if( ! strcmp(firstopt, "incoming_icp_average") )
 	{
 	    opt_pos = get_option_pos(line, 1);
 	    snprintf(new_buffer, 1024, "%s", &line[opt_pos]);
@@ -1314,7 +1315,7 @@ void populate_server_settings(struct w *widgets)
         	gtk_spin_button_set_value(GTK_SPIN_BUTTON(widgets->server_set_spinbutton[58]), val);
 	    }
 	}
-	if( ! strcmp(firstopt, "wccp2_weight") )
+	if( ! strcmp(firstopt, "incoming_http_average") )
 	{
 	    opt_pos = get_option_pos(line, 1);
 	    snprintf(new_buffer, 1024, "%s", &line[opt_pos]);
@@ -1329,7 +1330,7 @@ void populate_server_settings(struct w *widgets)
         	gtk_spin_button_set_value(GTK_SPIN_BUTTON(widgets->server_set_spinbutton[59]), val);
 	    }
 	}
-	if( ! strcmp(firstopt, "incoming_icp_average") )
+	if( ! strcmp(firstopt, "incoming_dns_average") )
 	{
 	    opt_pos = get_option_pos(line, 1);
 	    snprintf(new_buffer, 1024, "%s", &line[opt_pos]);
@@ -1344,7 +1345,7 @@ void populate_server_settings(struct w *widgets)
         	gtk_spin_button_set_value(GTK_SPIN_BUTTON(widgets->server_set_spinbutton[60]), val);
 	    }
 	}
-	if( ! strcmp(firstopt, "incoming_http_average") )
+	if( ! strcmp(firstopt, "min_icp_poll_cnt") )
 	{
 	    opt_pos = get_option_pos(line, 1);
 	    snprintf(new_buffer, 1024, "%s", &line[opt_pos]);
@@ -1359,7 +1360,7 @@ void populate_server_settings(struct w *widgets)
         	gtk_spin_button_set_value(GTK_SPIN_BUTTON(widgets->server_set_spinbutton[61]), val);
 	    }
 	}
-	if( ! strcmp(firstopt, "incoming_dns_average") )
+	if( ! strcmp(firstopt, "min_dns_poll_cnt") )
 	{
 	    opt_pos = get_option_pos(line, 1);
 	    snprintf(new_buffer, 1024, "%s", &line[opt_pos]);
@@ -1374,7 +1375,7 @@ void populate_server_settings(struct w *widgets)
         	gtk_spin_button_set_value(GTK_SPIN_BUTTON(widgets->server_set_spinbutton[62]), val);
 	    }
 	}
-	if( ! strcmp(firstopt, "min_icp_poll_cnt") )
+	if( ! strcmp(firstopt, "min_http_poll_cnt") )
 	{
 	    opt_pos = get_option_pos(line, 1);
 	    snprintf(new_buffer, 1024, "%s", &line[opt_pos]);
@@ -1389,7 +1390,8 @@ void populate_server_settings(struct w *widgets)
         	gtk_spin_button_set_value(GTK_SPIN_BUTTON(widgets->server_set_spinbutton[63]), val);
 	    }
 	}
-	if( ! strcmp(firstopt, "min_dns_poll_cnt") )
+*/
+	if( ! strcmp(firstopt, "max_open_disk_fds") )
 	{
 	    opt_pos = get_option_pos(line, 1);
 	    snprintf(new_buffer, 1024, "%s", &line[opt_pos]);
@@ -1404,7 +1406,7 @@ void populate_server_settings(struct w *widgets)
         	gtk_spin_button_set_value(GTK_SPIN_BUTTON(widgets->server_set_spinbutton[64]), val);
 	    }
 	}
-	if( ! strcmp(firstopt, "min_http_poll_cnt") )
+	if( ! strcmp(firstopt, "digest_bits_per_entry") )
 	{
 	    opt_pos = get_option_pos(line, 1);
 	    snprintf(new_buffer, 1024, "%s", &line[opt_pos]);
@@ -1419,7 +1421,7 @@ void populate_server_settings(struct w *widgets)
         	gtk_spin_button_set_value(GTK_SPIN_BUTTON(widgets->server_set_spinbutton[65]), val);
 	    }
 	}
-	if( ! strcmp(firstopt, "max_open_disk_fds") )
+	if( ! strcmp(firstopt, "digest_rebuild_period") )
 	{
 	    opt_pos = get_option_pos(line, 1);
 	    snprintf(new_buffer, 1024, "%s", &line[opt_pos]);
@@ -1434,7 +1436,7 @@ void populate_server_settings(struct w *widgets)
         	gtk_spin_button_set_value(GTK_SPIN_BUTTON(widgets->server_set_spinbutton[66]), val);
 	    }
 	}
-	if( ! strcmp(firstopt, "digest_bits_per_entry") )
+	if( ! strcmp(firstopt, "digest_rewrite_period") )
 	{
 	    opt_pos = get_option_pos(line, 1);
 	    snprintf(new_buffer, 1024, "%s", &line[opt_pos]);
@@ -1449,7 +1451,7 @@ void populate_server_settings(struct w *widgets)
         	gtk_spin_button_set_value(GTK_SPIN_BUTTON(widgets->server_set_spinbutton[67]), val);
 	    }
 	}
-	if( ! strcmp(firstopt, "digest_rebuild_period") )
+	if( ! strcmp(firstopt, "digest_swapout_chunk_size") )
 	{
 	    opt_pos = get_option_pos(line, 1);
 	    snprintf(new_buffer, 1024, "%s", &line[opt_pos]);
@@ -1464,7 +1466,7 @@ void populate_server_settings(struct w *widgets)
         	gtk_spin_button_set_value(GTK_SPIN_BUTTON(widgets->server_set_spinbutton[68]), val);
 	    }
 	}
-	if( ! strcmp(firstopt, "digest_rewrite_period") )
+	if( ! strcmp(firstopt, "digest_rebuild_chunk_percentage") )
 	{
 	    opt_pos = get_option_pos(line, 1);
 	    snprintf(new_buffer, 1024, "%s", &line[opt_pos]);
@@ -1479,7 +1481,7 @@ void populate_server_settings(struct w *widgets)
         	gtk_spin_button_set_value(GTK_SPIN_BUTTON(widgets->server_set_spinbutton[69]), val);
 	    }
 	}
-	if( ! strcmp(firstopt, "digest_swapout_chunk_size") )
+	if( ! strcmp(firstopt, "high_response_time_warning") )
 	{
 	    opt_pos = get_option_pos(line, 1);
 	    snprintf(new_buffer, 1024, "%s", &line[opt_pos]);
@@ -1494,7 +1496,7 @@ void populate_server_settings(struct w *widgets)
         	gtk_spin_button_set_value(GTK_SPIN_BUTTON(widgets->server_set_spinbutton[70]), val);
 	    }
 	}
-	if( ! strcmp(firstopt, "digest_rebuild_chunk_percentage") )
+	if( ! strcmp(firstopt, "high_page_fault_warning") )
 	{
 	    opt_pos = get_option_pos(line, 1);
 	    snprintf(new_buffer, 1024, "%s", &line[opt_pos]);
@@ -1509,7 +1511,7 @@ void populate_server_settings(struct w *widgets)
         	gtk_spin_button_set_value(GTK_SPIN_BUTTON(widgets->server_set_spinbutton[71]), val);
 	    }
 	}
-	if( ! strcmp(firstopt, "high_response_time_warning") )
+	if( ! strcmp(firstopt, "high_memory_warning") )
 	{
 	    opt_pos = get_option_pos(line, 1);
 	    snprintf(new_buffer, 1024, "%s", &line[opt_pos]);
@@ -1524,7 +1526,7 @@ void populate_server_settings(struct w *widgets)
         	gtk_spin_button_set_value(GTK_SPIN_BUTTON(widgets->server_set_spinbutton[72]), val);
 	    }
 	}
-	if( ! strcmp(firstopt, "high_page_fault_warning") )
+	if( ! strcmp(firstopt, "sleep_after_fork") )
 	{
 	    opt_pos = get_option_pos(line, 1);
 	    snprintf(new_buffer, 1024, "%s", &line[opt_pos]);
@@ -1539,7 +1541,7 @@ void populate_server_settings(struct w *widgets)
         	gtk_spin_button_set_value(GTK_SPIN_BUTTON(widgets->server_set_spinbutton[73]), val);
 	    }
 	}
-	if( ! strcmp(firstopt, "high_memory_warning") )
+	if( ! strcmp(firstopt, "minimum_expiry_time") )
 	{
 	    opt_pos = get_option_pos(line, 1);
 	    snprintf(new_buffer, 1024, "%s", &line[opt_pos]);
@@ -1554,7 +1556,7 @@ void populate_server_settings(struct w *widgets)
         	gtk_spin_button_set_value(GTK_SPIN_BUTTON(widgets->server_set_spinbutton[74]), val);
 	    }
 	}
-	if( ! strcmp(firstopt, "sleep_after_fork") )
+	if( ! strcmp(firstopt, "authenticate_cache_garbage_interval") )
 	{
 	    opt_pos = get_option_pos(line, 1);
 	    snprintf(new_buffer, 1024, "%s", &line[opt_pos]);
@@ -1569,7 +1571,7 @@ void populate_server_settings(struct w *widgets)
         	gtk_spin_button_set_value(GTK_SPIN_BUTTON(widgets->server_set_spinbutton[75]), val);
 	    }
 	}
-	if( ! strcmp(firstopt, "minimum_expiry_time") )
+	if( ! strcmp(firstopt, "authenticate_ttl") )
 	{
 	    opt_pos = get_option_pos(line, 1);
 	    snprintf(new_buffer, 1024, "%s", &line[opt_pos]);
@@ -1584,51 +1586,6 @@ void populate_server_settings(struct w *widgets)
         	gtk_spin_button_set_value(GTK_SPIN_BUTTON(widgets->server_set_spinbutton[76]), val);
 	    }
 	}
-	if( ! strcmp(firstopt, "max_filedesc") )
-	{
-	    opt_pos = get_option_pos(line, 1);
-	    snprintf(new_buffer, 1024, "%s", &line[opt_pos]);
-	    new_buffer[strlen(new_buffer)-1]='\0';
-	    for(i=0; new_buffer[i]!='\0'; i++)
-	      if( new_buffer[i]==' ' )
-	        break;
-	    new_buffer[i]='\0';
-	    if( chars_are_digits(new_buffer) )
-	    {
-        	val = atoi(new_buffer);
-        	gtk_spin_button_set_value(GTK_SPIN_BUTTON(widgets->server_set_spinbutton[77]), val);
-	    }
-	}
-	if( ! strcmp(firstopt, "authenticate_cache_garbage_interval") )
-	{
-	    opt_pos = get_option_pos(line, 1);
-	    snprintf(new_buffer, 1024, "%s", &line[opt_pos]);
-	    new_buffer[strlen(new_buffer)-1]='\0';
-	    for(i=0; new_buffer[i]!='\0'; i++)
-	      if( new_buffer[i]==' ' )
-	        break;
-	    new_buffer[i]='\0';
-	    if( chars_are_digits(new_buffer) )
-	    {
-        	val = atoi(new_buffer);
-        	gtk_spin_button_set_value(GTK_SPIN_BUTTON(widgets->server_set_spinbutton[78]), val);
-	    }
-	}
-	if( ! strcmp(firstopt, "authenticate_ttl") )
-	{
-	    opt_pos = get_option_pos(line, 1);
-	    snprintf(new_buffer, 1024, "%s", &line[opt_pos]);
-	    new_buffer[strlen(new_buffer)-1]='\0';
-	    for(i=0; new_buffer[i]!='\0'; i++)
-	      if( new_buffer[i]==' ' )
-	        break;
-	    new_buffer[i]='\0';
-	    if( chars_are_digits(new_buffer) )
-	    {
-        	val = atoi(new_buffer);
-        	gtk_spin_button_set_value(GTK_SPIN_BUTTON(widgets->server_set_spinbutton[79]), val);
-	    }
-	}
 	if( ! strcmp(firstopt, "authenticate_ip_ttl") )
 	{
 	    opt_pos = get_option_pos(line, 1);
@@ -1641,7 +1598,7 @@ void populate_server_settings(struct w *widgets)
 	    if( chars_are_digits(new_buffer) )
 	    {
         	val = atoi(new_buffer);
-        	gtk_spin_button_set_value(GTK_SPIN_BUTTON(widgets->server_set_spinbutton[80]), val);
+        	gtk_spin_button_set_value(GTK_SPIN_BUTTON(widgets->server_set_spinbutton[77]), val);
 	    }
 	}
 
@@ -1725,271 +1682,229 @@ void populate_server_settings(struct w *widgets)
 	    else
 	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[10]), 1);
 	}
-	if( ! strcmp(firstopt, "acl_uses_indirect_client") )
+	if( ! strcmp(firstopt, "half_closed_clients") )
 	{
 	    if( cmplowercase(line, "on") )
 	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[11]), 0);
 	    else
 	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[11]), 1);
 	}
-	if( ! strcmp(firstopt, "half_closed_clients") )
+	if( ! strcmp(firstopt, "httpd_suppress_version_string") )
 	{
-	    if( cmplowercase(line, "on") )
+	    if( cmplowercase(line, "on") && ! cmplowercase(line, "off") )
 	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[12]), 0);
 	    else
 	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[12]), 1);
 	}
-	if( ! strcmp(firstopt, "httpd_suppress_version_string") )
+	if( ! strcmp(firstopt, "via") )
 	{
-	    if( cmplowercase(line, "on") && ! cmplowercase(line, "off") )
+	    if( cmplowercase(line, "on") )
 	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[13]), 0);
 	    else
 	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[13]), 1);
 	}
-	if( ! strcmp(firstopt, "delay_pool_uses_indirect_client") )
+	if( ! strcmp(firstopt, "forwarded_for") )
 	{
 	    if( cmplowercase(line, "on") )
 	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[14]), 0);
 	    else
 	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[14]), 1);
 	}
-	if( ! strcmp(firstopt, "log_uses_indirect_client") )
+	if( ! strcmp(firstopt, "log_icp_queries") )
 	{
 	    if( cmplowercase(line, "on") )
 	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[15]), 0);
 	    else
 	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[15]), 1);
 	}
-	if( ! strcmp(firstopt, "via") )
+	if( ! strcmp(firstopt, "client_db") )
 	{
 	    if( cmplowercase(line, "on") )
 	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[16]), 0);
 	    else
 	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[16]), 1);
 	}
-	if( ! strcmp(firstopt, "forwarded_for") )
+	if( ! strcmp(firstopt, "icp_hit_stale") )
 	{
 	    if( cmplowercase(line, "on") )
 	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[17]), 0);
 	    else
 	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[17]), 1);
 	}
-	if( ! strcmp(firstopt, "log_icp_queries") )
+	if( ! strcmp(firstopt, "query_icmp") )
 	{
 	    if( cmplowercase(line, "on") )
 	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[18]), 0);
 	    else
 	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[18]), 1);
 	}
-	if( ! strcmp(firstopt, "httpd_accel_no_pmtu_disc") )
+	if( ! strcmp(firstopt, "test_reachability") )
 	{
 	    if( cmplowercase(line, "on") )
 	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[19]), 0);
 	    else
 	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[19]), 1);
 	}
-	if( ! strcmp(firstopt, "client_db") )
+	if( ! strcmp(firstopt, "buffered_logs") )
 	{
 	    if( cmplowercase(line, "on") )
 	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[20]), 0);
 	    else
 	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[20]), 1);
 	}
-	if( ! strcmp(firstopt, "icp_hit_stale") )
+	if( ! strcmp(firstopt, "reload_into_ims") )
 	{
 	    if( cmplowercase(line, "on") )
 	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[21]), 0);
 	    else
 	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[21]), 1);
 	}
-	if( ! strcmp(firstopt, "query_icmp") )
+	if( ! strcmp(firstopt, "global_internal_static") )
 	{
 	    if( cmplowercase(line, "on") )
 	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[22]), 0);
 	    else
 	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[22]), 1);
 	}
-	if( ! strcmp(firstopt, "test_reachability") )
+	if( ! strcmp(firstopt, "short_icon_urls") )
 	{
-	    if( cmplowercase(line, "on") )
+	    if( cmplowercase(line, "on") && ! cmplowercase(line, "off") )
 	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[23]), 0);
 	    else
 	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[23]), 1);
 	}
-	if( ! strcmp(firstopt, "buffered_logs") )
+	if( ! strcmp(firstopt, "offline_mode") )
 	{
 	    if( cmplowercase(line, "on") )
 	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[24]), 0);
 	    else
 	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[24]), 1);
 	}
-	if( ! strcmp(firstopt, "reload_into_ims") )
+	if( ! strcmp(firstopt, "nonhierarchical_direct") )
 	{
-	    if( cmplowercase(line, "on") )
+	    if( cmplowercase(line, "on") && ! cmplowercase(line, "off") )
 	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[25]), 0);
 	    else
 	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[25]), 1);
 	}
-	if( ! strcmp(firstopt, "global_internal_static") )
+	if( ! strcmp(firstopt, "prefer_direct") )
 	{
 	    if( cmplowercase(line, "on") )
 	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[26]), 0);
 	    else
 	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[26]), 1);
 	}
-	if( ! strcmp(firstopt, "short_icon_urls") )
+	if( ! strcmp(firstopt, "strip_query_terms") )
 	{
-	    if( cmplowercase(line, "on") && ! cmplowercase(line, "off") )
+	    if( cmplowercase(line, "on") )
 	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[27]), 0);
 	    else
 	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[27]), 1);
 	}
-	if( ! strcmp(firstopt, "offline_mode") )
+	if( ! strcmp(firstopt, "redirector_bypass") )
 	{
 	    if( cmplowercase(line, "on") )
 	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[28]), 0);
 	    else
 	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[28]), 1);
 	}
-	if( ! strcmp(firstopt, "nonhierarchical_direct") )
+	if( ! strcmp(firstopt, "ignore_unknown_nameservers") )
 	{
-	    if( cmplowercase(line, "on") && ! cmplowercase(line, "off") )
+	    if( cmplowercase(line, "on") )
 	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[29]), 0);
 	    else
 	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[29]), 1);
 	}
-	if( ! strcmp(firstopt, "prefer_direct") )
+	if( ! strcmp(firstopt, "client_persistent_connections") )
 	{
-	    if( cmplowercase(line, "on") )
+	    if( cmplowercase(line, "on") && ! cmplowercase(line, "off") )
 	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[30]), 0);
 	    else
 	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[30]), 1);
 	}
-	if( ! strcmp(firstopt, "strip_query_terms") )
+	if( ! strcmp(firstopt, "server_persistent_connections") )
 	{
-	    if( cmplowercase(line, "on") )
+	    if( cmplowercase(line, "on") && ! cmplowercase(line, "off") )
 	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[31]), 0);
 	    else
 	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[31]), 1);
 	}
-	if( ! strcmp(firstopt, "redirector_bypass") )
+	if( ! strcmp(firstopt, "persistent_connection_after_error") )
 	{
-	    if( cmplowercase(line, "on") )
+	    if( cmplowercase(line, "on") && ! cmplowercase(line, "off") )
 	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[32]), 0);
 	    else
 	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[32]), 1);
 	}
-	if( ! strcmp(firstopt, "ignore_unknown_nameservers") )
+	if( ! strcmp(firstopt, "detect_broken_pconn") )
 	{
-	    if( cmplowercase(line, "on") )
+	    if( cmplowercase(line, "on") && ! cmplowercase(line, "off") )
 	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[33]), 0);
 	    else
 	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[33]), 1);
 	}
-	if( ! strcmp(firstopt, "client_persistent_connections") )
+	if( ! strcmp(firstopt, "balance_on_multiple_ip") )
 	{
 	    if( cmplowercase(line, "on") && ! cmplowercase(line, "off") )
 	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[34]), 0);
 	    else
 	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[34]), 1);
 	}
-	if( ! strcmp(firstopt, "server_persistent_connections") )
+	if( ! strcmp(firstopt, "pipeline_prefetch") )
 	{
-	    if( cmplowercase(line, "on") && ! cmplowercase(line, "off") )
+	    if( cmplowercase(line, "on") )
 	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[35]), 0);
 	    else
 	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[35]), 1);
 	}
-	if( ! strcmp(firstopt, "persistent_connection_after_error") )
+	if( ! strcmp(firstopt, "request_entities") )
 	{
-	    if( cmplowercase(line, "on") && ! cmplowercase(line, "off") )
+	    if( cmplowercase(line, "on") )
 	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[36]), 0);
 	    else
 	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[36]), 1);
 	}
-	if( ! strcmp(firstopt, "detect_broken_pconn") )
+	if( ! strcmp(firstopt, "ie_refresh") )
 	{
-	    if( cmplowercase(line, "on") && ! cmplowercase(line, "off") )
+	    if( cmplowercase(line, "on") )
 	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[37]), 0);
 	    else
 	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[37]), 1);
 	}
-	if( ! strcmp(firstopt, "balance_on_multiple_ip") )
+	if( ! strcmp(firstopt, "vary_ignore_expire") )
 	{
-	    if( cmplowercase(line, "on") && ! cmplowercase(line, "off") )
+	    if( cmplowercase(line, "on") )
 	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[38]), 0);
 	    else
 	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[38]), 1);
 	}
-	if( ! strcmp(firstopt, "pipeline_prefetch") )
+	if( ! strcmp(firstopt, "relaxed_header_parser") )
 	{
 	    if( cmplowercase(line, "on") )
 	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[39]), 0);
 	    else
 	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[39]), 1);
 	}
-	if( ! strcmp(firstopt, "request_entities") )
+	if( ! strcmp(firstopt, "retry_on_error") )
 	{
-	    if( cmplowercase(line, "on") )
+	    if( cmplowercase(line, "on") && ! cmplowercase(line, "off") )
 	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[40]), 0);
 	    else
 	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[40]), 1);
 	}
-	if( ! strcmp(firstopt, "ie_refresh") )
+	if( ! strcmp(firstopt, "wccp2_rebuild_wait") )
 	{
 	    if( cmplowercase(line, "on") )
 	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[41]), 0);
 	    else
 	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[41]), 1);
 	}
-	if( ! strcmp(firstopt, "vary_ignore_expire") )
-	{
-	    if( cmplowercase(line, "on") )
-	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[42]), 0);
-	    else
-	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[42]), 1);
-	}
-	if( ! strcmp(firstopt, "relaxed_header_parser") )
-	{
-	    if( cmplowercase(line, "on") )
-	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[43]), 0);
-	    else
-	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[43]), 1);
-	}
-	if( ! strcmp(firstopt, "cache_vary") )
-	{
-	    if( cmplowercase(line, "on") )
-	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[44]), 0);
-	    else
-	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[44]), 1);
-	}
-	if( ! strcmp(firstopt, "retry_on_error") )
-	{
-	    if( cmplowercase(line, "on") && ! cmplowercase(line, "off") )
-	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[45]), 0);
-	    else
-	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[45]), 1);
-	}
-	if( ! strcmp(firstopt, "collapsed_forwarding") )
-	{
-	    if( cmplowercase(line, "on") )
-	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[46]), 0);
-	    else
-	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[46]), 1);
-	}
-	if( ! strcmp(firstopt, "wccp2_rebuild_wait") )
-	{
-	    if( cmplowercase(line, "on") )
-	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[47]), 0);
-	    else
-	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[47]), 1);
-	}
 	if( ! strcmp(firstopt, "digest_generation") )
 	{
 	    if( cmplowercase(line, "on") && ! cmplowercase(line, "off") )
-	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[48]), 0);
+	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[42]), 0);
 	    else
-	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[48]), 1);
+	      gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[42]), 1);
 	}
 
 
