@@ -1,5 +1,5 @@
 /* GADMIN-SQUID - An easy to use GTK+ frontend for the Squid proxy server.
- * Copyright (C) 2006 - 2008 Magnus Loef <magnus-swe@telia.com> 
+ * Copyright (C) 2006 - 2009 Magnus Loef <magnus-swe@telia.com> 
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -81,7 +81,7 @@ int conf_ok(gchar *file_path)
     }
     fclose(fp);
     free(line);
-    
+
     if( good >= 3 )
       retval = 1;
 
@@ -89,6 +89,31 @@ int conf_ok(gchar *file_path)
 }
 
 
+/* Automated configuration backups for new versions */
+void backup_configuration(struct w *widgets)
+{
+    gchar *cmd, *info;
+
+    if( ! file_exists(SQUID_CONF_BACKUP) && file_exists(SQUID_CONF) )
+    {
+	cmd = g_strdup_printf("cp %s %s", SQUID_CONF, SQUID_CONF_BACKUP);
+        if( ! run_command(cmd) )
+	{
+	    info = g_strdup_printf(_("Error: Could not backup the current configuration:\n%s\n"), SQUID_CONF);
+	    show_info(info);
+	    g_free(info);
+	}
+	else
+	{
+	    info = g_strdup_printf(_("The configuration was backed up here for safety:\n%s\n"), SQUID_CONF_BACKUP);
+	    show_info(info);
+	    g_free(info);
+	}
+	g_free(cmd);
+    }
+}
+
+
 void add_standard_conf(struct w *widgets)
 {
     /* Adds default squid.conf configurations */
@@ -134,7 +159,7 @@ void add_standard_conf(struct w *widgets)
     /* Make the standard squid configuration */
     conf = g_strconcat("",
     "http_port 0.0.0.0:3128\n",
-    "#https_port 0.0.0.0:3128 cert=/etc/gadminsquid/certificate.pem\n",
+    "#https_port 0.0.0.0:3128 cert=/etc/gadmin-squid/certificate.pem\n",
 
     "visible_hostname host.example.org\n",
     "httpd_suppress_version_string off\n",
@@ -184,8 +209,7 @@ void add_standard_conf(struct w *widgets)
     "dns_defnames off\n",
     "authenticate_cache_garbage_interval 1 hour\n",
     "authenticate_ttl 1 hour\n",
-    "authenticate_ip_ttl 0 seconds\n",
-    "wais_relay_port 0\n",
+    "authenticate_ip_ttl 20 seconds\n",
     "request_header_max_size 20 KB\n",
     "request_body_max_size 0 KB\n",
     "quick_abort_min 16 KB\n",
@@ -196,8 +220,6 @@ void add_standard_conf(struct w *widgets)
     "positive_dns_ttl 6 hours\n",
     "negative_dns_ttl 1 minute\n",
     "range_offset_limit 0 KB\n",
-    "collapsed_forwarding off\n",
-    "refresh_stale_hit 0 seconds\n",
     "forward_timeout 4 minutes\n",
     "connect_timeout 1 minute\n",
     "peer_connect_timeout 30 seconds\n",
@@ -209,9 +231,6 @@ void add_standard_conf(struct w *widgets)
     "pconn_timeout 120 seconds\n",
     "ident_timeout 10 seconds\n",
     "shutdown_lifetime 30 seconds\n",
-    "acl_uses_indirect_client on\n",
-    "delay_pool_uses_indirect_client on\n",
-    "log_uses_indirect_client on\n",
     "reply_header_max_size 20 KB\n",
     "cache_mgr root\n",
     "mail_from ", SERVER_USER, "@example.org\n",
@@ -219,10 +238,9 @@ void add_standard_conf(struct w *widgets)
     "cache_effective_user ",  SERVER_USER, "\n",
     "cache_effective_group ", SERVER_GROUP, "\n",
     "umask 027\n",
-    "announce_period 0\n",
+    "announce_period 50 seconds\n",
     "announce_host tracker.ircache.net\n",
     "announce_port 3131\n",
-    "httpd_accel_no_pmtu_disc off\n",
     "logfile_rotate 0\n",
     "tcp_recv_bufsize 0 bytes\n",
     "memory_pools on\n",
@@ -263,12 +281,6 @@ void add_standard_conf(struct w *widgets)
     "wccp2_weight 10000\n",
     "wccp_address 0.0.0.0\n",
     "wccp2_address 0.0.0.0\n",
-    "incoming_icp_average 6\n",
-    "incoming_http_average 4\n",
-    "incoming_dns_average 4\n",
-    "min_icp_poll_cnt 8\n",
-    "min_dns_poll_cnt 8\n",
-    "min_http_poll_cnt 8\n",
     "max_open_disk_fds 0\n",
     "offline_mode off\n",
     "uri_whitespace strip\n",
@@ -294,17 +306,14 @@ void add_standard_conf(struct w *widgets)
     "request_entities off\n",
     "high_response_time_warning 0\n",
     "high_page_fault_warning 0\n",
-    "high_memory_warning 0\n",
+    "high_memory_warning 30 bytes\n",
     "store_dir_select_algorithm least-load\n",
     "ie_refresh off\n",
     "vary_ignore_expire off\n",
     "sleep_after_fork 0\n",
     "minimum_expiry_time 60 seconds\n",
     "relaxed_header_parser on\n",
-    "max_filedesc 1024\n",
-    "cache_vary on\n",
-
-    "acl all src 0.0.0.0/0.0.0.0\n",
+    "\n\n",
     "acl our_networks src 192.168.0.0/24 192.168.1.0/24\n",
     "acl localhost src 127.0.0.1/255.255.255.255\n",
     "acl to_localhost dst 127.0.0.0/8\n",
@@ -323,26 +332,35 @@ void add_standard_conf(struct w *widgets)
     "acl Safe_ports port 591		# filemaker\n",
     "acl Safe_ports port 777		# multiling http\n",
     "acl CONNECT method CONNECT\n",
-
+    "\n",
     "http_access allow localhost\n",
     "http_access allow our_networks\n",
     "http_reply_access allow all\n",
-    "broken_vary_encoding allow apache\n",
     "icp_access allow all\n",
     "miss_access allow all\n",
-    "reply_body_max_size 0 allow all\n",
     "http_access deny !Safe_ports\n",
     "http_access deny CONNECT !SSL_ports\n",
     "http_access deny to_localhost\n",
-    "follow_x_forwarded_for deny all\n",
     "ident_lookup_access deny all\n",
     "cache deny QUERY\n",
     "http_access deny all\n",
     "snmp_access deny all\n",
+    NULL);
+
+
+/* Has commented gui settings... */
+/*
+    "incoming_icp_average 6\n",
+    "incoming_http_average 4\n",
+    "incoming_dns_average 4\n",
+    "min_icp_poll_cnt 8\n",
+    "min_dns_poll_cnt 8\n",
+    "min_http_poll_cnt 8\n",
+*/
 
 
 /* Unhandeled settings follow... */
-
+/*
     "logformat squid  %ts.%03tu %6tr %>a %Ss/%03Hs %<st %rm %ru %un %Sh/%<A %mt\n",
     "logformat squidmime  %ts.%03tu %6tr %>a %Ss/%03Hs %<st %rm %ru %un %Sh/%<A %mt [%>h] [%<h]\n",
     "logformat common %>a %ui %un [%tl] \"%rm %ru HTTP/%rv\" %Hs %<st %Ss:%Sh\n",
@@ -385,8 +403,9 @@ void add_standard_conf(struct w *widgets)
     "#auth_param basic realm Squid proxy-caching web server\n",
     "#auth_param basic credentialsttl 2 hours\n",
     "#auth_param basic casesensitive off\n",
-
+*/
     /* Delay pools must be placed after the ACL's */
+/*
     "delay_pools 0\n",
     "#delay_pools 2      # 2 delay pools\n",
     "#delay_class 1 2    # pool 1 is a class 2 pool\n",
@@ -413,6 +432,7 @@ void add_standard_conf(struct w *widgets)
     "#neighbor_type_domain cache.foo.org sibling .com .net\n",
     "#neighbor_type_domain cache.foo.org sibling .au .de\n",
     NULL);
+*/
     /* End of default configuration for squid */
 
     fputs(conf, fp);
